==> aws-android-sdk-cognito-2.1.8-sources.jar: main/java/com/amazonaws/services/kinesis/model/transform/SequenceNumberRangeJsonUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.kinesis.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.kinesis.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * Sequence Number Range JSON Unmarshaller
 */
public class SequenceNumberRangeJsonUnmarshaller implements Unmarshaller<SequenceNumberRange, JsonUnmarshallerContext> {

    public SequenceNumberRange unmarshall(JsonUnmarshallerContext context) throws Exception {
        SequenceNumberRange sequenceNumberRange = new SequenceNumberRange();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.currentToken;
        if (token == null) token = context.nextToken();
        if (token == VALUE_NULL) return null;

        while (true) {
            if (token == null) break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("StartingSequenceNumber", targetDepth)) {
                    context.nextToken();
                    sequenceNumberRange.setStartingSequenceNumber(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("EndingSequenceNumber", targetDepth)) {
                    context.nextToken();
                    sequenceNumberRange.setEndingSequenceNumber(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null || context.getLastParsedParentElement().equals(currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth) break;
                }
            }

            token = context.nextToken();
        }
        
        return sequenceNumberRange;
    }

    private static SequenceNumberRangeJsonUnmarshaller instance;
    public static SequenceNumberRangeJsonUnmarshaller getInstance() {
        if (instance == null) instance = new SequenceNumberRangeJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-cognito-2.1.9-sources.jar: main/java/com/amazonaws/services/kinesis/model/transform/SequenceNumberRangeJsonUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.kinesis.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.kinesis.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * Sequence Number Range JSON Unmarshaller
 */
public class SequenceNumberRangeJsonUnmarshaller implements Unmarshaller<SequenceNumberRange, JsonUnmarshallerContext> {

    public SequenceNumberRange unmarshall(JsonUnmarshallerContext context) throws Exception {
        SequenceNumberRange sequenceNumberRange = new SequenceNumberRange();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            
            if (name.equals("StartingSequenceNumber")) {
                sequenceNumberRange.setStartingSequenceNumber(StringJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            if (name.equals("EndingSequenceNumber")) {
                sequenceNumberRange.setEndingSequenceNumber(StringJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            {
                reader.skipValue();
            }
            
        }
        reader.endObject();
        
        return sequenceNumberRange;
    }

    private static SequenceNumberRangeJsonUnmarshaller instance;
    public static SequenceNumberRangeJsonUnmarshaller getInstance() {
        if (instance == null) instance = new SequenceNumberRangeJsonUnmarshaller();
        return instance;
    }
}
